@@ -6,11 +6,35 @@
 
 #pragma once
 
-#include <QImage>
 #include <QRunnable>
 
 #include "potdprovider.h"
 
+struct PotdProviderData {
+    QUrl remoteUrl;
+    QUrl infoUrl;
+    QString localPath;
+    QString title;
+    QString author;
+    QImage image;
+};
+Q_DECLARE_METATYPE(PotdProviderData)
+
+class LoadImageDataThread : public QObject, public QRunnable
+{
+    Q_OBJECT
+
+public:
+    explicit LoadImageDataThread(const QString &filePath);
+    void run() override;
+
+Q_SIGNALS:
+    void done(const PotdProviderData &data);
+
+private:
+    QString m_localPath;
+};
+
 /**
  * This class provides pictures from the local cache.
  */
@@ -33,6 +57,8 @@ public:
      */
     QString identifier() const override;
 
+    QString localPath() const override;
+
     /**
      * Returns whether a picture with the given @p identifier and @p args is cached.
      */
@@ -44,26 +70,12 @@ public:
     static QString identifierToPath(const QString &identifier, const QVariantList &args);
 
 private Q_SLOTS:
-    void triggerFinished(const PotdProviderData &data);
+    void slotFinished(const PotdProviderData &data);
 
 private:
     QString mIdentifier;
     QVariantList m_args;
-};
-
-class LoadImageThread : public QObject, public QRunnable
-{
-    Q_OBJECT
-
-public:
-    explicit LoadImageThread(const QString &filePath);
-    void run() override;
-
-Q_SIGNALS:
-    void done(const PotdProviderData &data);
-
-private:
-    QString m_filePath;
+    QString m_localPath;
 };
 
 class SaveImageThread : public QObject, public QRunnable
@@ -75,7 +87,7 @@ public:
     void run() override;
 
 Q_SIGNALS:
-    void done(const QString &source, const PotdProviderData &data);
+    void done(const QString &localPath);
 
 private:
     QString m_identifier;
